@@ -4,7 +4,7 @@ not import dcmstack.
 import sys
 
 _version_major = 0
-_version_minor = 8
+_version_minor = 9
 _version_micro = 0
 _version_extra = ''
 __version__ = "%s.%s.%s%s" % (_version_major,
@@ -24,17 +24,17 @@ description = 'Stack DICOM images into volumes and convert to Nifti'
 
 # Hard dependencies
 install_requires = ['pydicom >= 0.9.7',
-                    'nibabel >= 2.1.0',
+                    'nibabel >= 2.5.1',
+                    'pylibjpeg-libjpeg ; python_version >= "3.7"',
                    ]
-# Add version specific dependencies
-if sys.version_info < (2, 6):
-    raise Exception("must use python 2.6 or greater")
-elif sys.version_info < (2, 7):
-    install_requires.append('ordereddict')
 
 # Extra requirements for building documentation and testing
 extras_requires = {'doc':  ["sphinx", "numpydoc"],
-                   'test': ["nose"],
+                   'test': [
+                        'pytest <= 4.6 ; python_version == "2.7"',
+                        'pytest ; python_version > "2.7"',
+                        'pytest-cov',
+                    ],
                   }
 
 
