@@ -16,7 +16,12 @@ prog_descrip = """Work with extended Nifti files created by dcmstack"""
 def main(argv=sys.argv):
     #Setup the top level parser
     arg_parser = argparse.ArgumentParser(description=prog_descrip)
-    sub_parsers = arg_parser.add_subparsers(title="Subcommands")
+    if sys.version_info > (3, 7):
+        sub_parsers = arg_parser.add_subparsers(title="Subcommands",
+                                                dest='cmd',
+                                                required=True)
+    else:
+        sub_parsers = arg_parser.add_subparsers(title="Subcommands", dest='cmd')
 
     #Split command
     split_help = ("Split src_nii file along a dimension. Defaults to the slice "
